import { Store } from 'pullstate';
export const initialState = {
    fileDetails: {},
    collectionDetails: {}
};
export const UIStore = new Store(initialState);
export const resetRucioCaches = () => {
    UIStore.update(s => {
        s.fileDetails = {};
        s.collectionDetails = {};
    });
};
